FileFormats-medimage-fsl Extras
===============================

.. image:: https://github.com/nipype/pydra-freesurfer/actions/workflows/ci-cd.yaml/badge.svg
    :target: https://github.com/nipype/pydra-freesurfer/actions/workflows/ci-cd.yaml


This is a extras module for the `fileformats-vendor-fsl <https://github.com/nipype/pydra-fsl/>`__
fileformats extension package, which provides additional functionality to format classes (i.e. aside
from basic identification and validation), such as conversion tools, metadata parsers,
sample data generators, etc...


Quick Installation
------------------

This extension can be installed for Python 3 using *pip*::

    $ pip3 install fileformats-vendor-fsl-extras

This will install the package, base packages, and any other dependencies required to
implement the extra functionality.

License
-------

This work is licensed under a
`Creative Commons Attribution 4.0 International License <http://creativecommons.org/licenses/by/4.0/>`_

.. image:: https://i.creativecommons.org/l/by/4.0/88x31.png
  :target: http://creativecommons.org/licenses/by/4.0/
  :alt: Creative Commons Attribution 4.0 International License
